.. include:: ../README.rst

Work using orix
---------------

* P. Harrison, X. Zhou, S. M. Das, P. Lhuissier, C. H. Liebscher, M. Herbig, W. Ludwig,
  E. F. Rauch: Reconstructing Dual-Phase Nanometer Scale Grains within a Pearlitic Steel
  Tip in 3D through 4D-Scanning Precession Electron Diffraction Tomography and Automated
  Crystal Orientation Mapping, *Ultramicroscopy* 113536 (2022) (`journal
  <https://doi.org/10.1016/j.ultramic.2022.113536>`__).
* N. Cautaerts, P. Crout, H. W. Ånes, E. Prestat, J. Jeong, G. Dehm, C. H. Liebscher:
  Free, flexible and fast: Orientation mapping using the multi-core and GPU-accelerated
  template matching capabilities in the python-based open source 4D-STEM analysis
  toolbox Pyxem, *Ultramicroscopy* 113517 (2022) (`journal
  <https://doi.org/10.1016/j.ultramic.2022.113517>`__, `arXiv
  <https://arxiv.org/abs/2111.07347>`__).
* D. N. Johnstone, B. H. Martineau, P. Crout, P. A. Midgley, A. S. Eggeman:
  Density-based clustering of crystal (mis)orientations and the orix Python library,
  *Journal of Applied Crystallography* 53(5) (2020) (`journal
  <https://doi.org/10.1107/S1600576720011103>`__, `arXiv
  <https://arxiv.org/abs/2001.02716>`__).

.. toctree::
    :hidden:

    installation.rst

.. toctree::
    :hidden:
    :caption: User guide

    crystal_geometry.rst
    orientations.rst
    vectors.rst
    clustering_of_orientations.rst
    crystallographic_maps.rst

.. toctree::
    :hidden:
    :caption: Help & reference

    reference.rst
    bibliography.rst
    changelog.rst
    contributing.rst
    related_projects.rst
